@@ -80,22 +80,23 @@ func (ui *UI) AnalyzePath(path string, parentDir *analyze.Dir) error {
 	go ui.updateProgress()
 
 	go func() {
-		ui.currentDir = ui.Analyzer.AnalyzeDir(path, ui.CreateIgnoreFunc())
+		currentDir := ui.Analyzer.AnalyzeDir(path, ui.CreateIgnoreFunc())
 		runtime.GC()
 
 		if parentDir != nil {
-			ui.currentDir.Parent = parentDir
-			parentDir.Files = parentDir.Files.RemoveByName(ui.currentDir.Name)
-			parentDir.Files.Append(ui.currentDir)
+			currentDir.Parent = parentDir
+			parentDir.Files = parentDir.Files.RemoveByName(currentDir.Name)
+			parentDir.Files.Append(currentDir)
 
 			links := make(analyze.AlreadyCountedHardlinks, 10)
 			ui.topDir.UpdateStats(links)
 		} else {
 			ui.topDirPath = path
-			ui.topDir = ui.currentDir
+			ui.topDir = currentDir
 		}
 
 		ui.app.QueueUpdateDraw(func() {
+			ui.currentDir = currentDir
 			ui.showDir()
 			ui.pages.RemovePage("progress")
 		})
@@ -220,6 +221,10 @@ func (ui *UI) deleteSelected(shouldEmpty bool) {
 }
 
 func (ui *UI) showFile() *tview.TextView {
+	if ui.currentDir == nil {
+		return nil
+	}
+
 	row, column := ui.table.GetSelection()
 	selectedFile := ui.table.GetCell(row, column).GetReference().(analyze.Item)
 	if selectedFile.IsDir() {
@@ -305,6 +310,10 @@ func (ui *UI) showFile() *tview.TextView {
 }
 
 func (ui *UI) showInfo() {
+	if ui.currentDir == nil {
+		return
+	}
+
 	var content, numberColor string
 	row, column := ui.table.GetSelection()
 	selectedFile := ui.table.GetCell(row, column).GetReference().(analyze.Item)
