@@ -89,6 +89,26 @@ func TestAnalyzeByItemCountAsc(t *testing.T) {
 	assert.Contains(t, ui.table.GetCell(3, 0).Text, "aaa")
 }
 
+func TestAnalyzeByMtime(t *testing.T) {
+	ui := getAnalyzedPathWithSorting("mtime", "desc", false)
+
+	assert.Equal(t, 4, ui.table.GetRowCount())
+	assert.Contains(t, ui.table.GetCell(0, 0).Text, "aaa")
+	assert.Contains(t, ui.table.GetCell(1, 0).Text, "bbb")
+	assert.Contains(t, ui.table.GetCell(2, 0).Text, "ccc")
+	assert.Contains(t, ui.table.GetCell(3, 0).Text, "ddd")
+}
+
+func TestAnalyzeByMtimeAsc(t *testing.T) {
+	ui := getAnalyzedPathWithSorting("mtime", "asc", false)
+
+	assert.Equal(t, 4, ui.table.GetRowCount())
+	assert.Contains(t, ui.table.GetCell(0, 0).Text, "ddd")
+	assert.Contains(t, ui.table.GetCell(1, 0).Text, "ccc")
+	assert.Contains(t, ui.table.GetCell(2, 0).Text, "bbb")
+	assert.Contains(t, ui.table.GetCell(3, 0).Text, "aaa")
+}
+
 func TestSetSorting(t *testing.T) {
 	ui := getAnalyzedPathWithSorting("itemCount", "asc", false)
 
@@ -103,6 +123,18 @@ func TestSetSorting(t *testing.T) {
 	assert.Equal(t, "asc", ui.sortOrder)
 }
 
+func TestSetSortingWithoutCurrentDir(t *testing.T) {
+	simScreen := testapp.CreateSimScreen(50, 50)
+	defer simScreen.Fini()
+
+	app := testapp.CreateMockedApp(true)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true)
+
+	// calling setSorting does nothing if we have not current dir
+	ui.setSorting("itemCount")
+	assert.Equal(t, "size", ui.sortBy)
+}
+
 func getAnalyzedPathWithSorting(sortBy string, sortOrder string, apparentSize bool) *UI {
 	simScreen := testapp.CreateSimScreen(50, 50)
 	defer simScreen.Fini()
