@@ -169,13 +169,13 @@ func TestRescanDir(t *testing.T) {
 
 	<-ui.done // wait for analyzer
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
-	assert.Equal(t, parentDir, ui.currentDir.Parent)
-
 	for _, f := range ui.app.(*testapp.MockedApp).UpdateDraws {
 		f()
 	}
 
+	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, parentDir, ui.currentDir.Parent)
+
 	assert.Equal(t, 5, ui.table.GetRowCount())
 	assert.Contains(t, ui.table.GetCell(0, 0).Text, "/..")
 	assert.Contains(t, ui.table.GetCell(1, 0).Text, "aaa")
@@ -204,6 +204,18 @@ func TestFileSelected(t *testing.T) {
 	assert.Contains(t, ui.table.GetCell(0, 0).Text, "aaa")
 }
 
+func TestSelectedWithoutCurrentDir(t *testing.T) {
+	simScreen := testapp.CreateSimScreen(50, 50)
+	defer simScreen.Fini()
+
+	app := testapp.CreateMockedApp(true)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true)
+
+	ui.fileItemSelected(1, 0)
+
+	assert.Nil(t, ui.currentDir)
+}
+
 func TestBeforeDraw(t *testing.T) {
 	screen := tcell.NewSimulationScreen("UTF-8")
 	err := screen.Init()
@@ -376,11 +388,11 @@ func getAnalyzedPathMockedApp(t *testing.T, useColors, apparentSize bool, mocked
 
 	<-ui.done // wait for analyzer
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
-
 	for _, f := range ui.app.(*testapp.MockedApp).UpdateDraws {
 		f()
 	}
 
+	assert.Equal(t, "test_dir", ui.currentDir.Name)
+
 	return ui
 }
